@@ -7,6 +7,8 @@ use Env qw( @PATH );
 use Cwd qw( cwd );
 use base qw( Alien::Base::ModuleBuild );
 
+$ENV{ALIEN_BLIB} = 0;
+
 my $libffi_version = '3.2.1';
 
 # some weird older perl CPAN.pm or Module::Build or something.
@@ -51,8 +53,6 @@ sub new
       }
       # TODO: also need to copy libffi.a => ffi.lib
     }
-    
-    $args{build_requires}->{'Alien::MSYS'} = 0;
   }
   
   $args{alien_name} = 'libffi';
@@ -69,6 +69,11 @@ sub new
   };
   
   my $self = $class->SUPER::new(%args);
+
+  if($^O eq 'MSWin32' && ($Alien::Base::ModuleBuild::Force || !$self->alien_check_installed_version))
+  {
+    $self->_add_prereq( 'build_requires' => 'Alien::MSYS' => 0 );
+  }
   
   $self;
 }
@@ -81,6 +86,6 @@ sub new
   @PATH = grep { $_ ne $msys_path && $_ !~ /GnuWin32/i } @PATH;
   unshift @PATH, $msys_path;
   $self->SUPER::do_system(@rest);
-} if $^O eq 'MSWin32';
+} if $^O eq 'MSWin32' && eval q{ use Alien::MSYS (); 1 };
 
 1;
